==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/NetworkACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.WebPubSubRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network ACL
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 */
public data class NetworkACLArgs(
    public val allow: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val deny: Output<List<Either<String, WebPubSubRequestType>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs =
        com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkACLArgs].
 */
@PulumiTagMarker
public class NetworkACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var deny: Output<List<Either<String, WebPubSubRequestType>>>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("quduagkkgfhvyntk")
    public suspend fun allow(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.allow = value
    }

    @JvmName("bucpfdyrtrofpfdb")
    public suspend fun allow(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("cwmrxxdhmvudrnlc")
    public suspend fun allow(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("bibtloxvvgldshaj")
    public suspend fun deny(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.deny = value
    }

    @JvmName("geoatdhldqcwbxkl")
    public suspend fun deny(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("nlqcjxgaabtnakig")
    public suspend fun deny(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("jjrrfqljamvkrnwr")
    public suspend fun allow(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("xfhlarjsrufyplwp")
    public suspend fun allow(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("pjpjdpsnxjdbolha")
    public suspend fun deny(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("mtqxaojdjvyipsff")
    public suspend fun deny(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    internal fun build(): NetworkACLArgs = NetworkACLArgs(
        allow = allow,
        deny = deny,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/NetworkACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.WebPubSubRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network ACL
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 */
public data class NetworkACLArgs(
    public val allow: Output<List<Either<String, WebPubSubRequestType>>>? = null,
    public val deny: Output<List<Either<String, WebPubSubRequestType>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs =
        com.pulumi.azurenative.webpubsub.inputs.NetworkACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkACLArgs].
 */
@PulumiTagMarker
public class NetworkACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, WebPubSubRequestType>>>? = null

    private var deny: Output<List<Either<String, WebPubSubRequestType>>>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("bqaimrpjaxhccrvm")
    public suspend fun allow(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.allow = value
    }

    @JvmName("llutdtdpfqflqrot")
    public suspend fun allow(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("nwlynnwaxekyyggr")
    public suspend fun allow(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("xxrsgyekrkoygfhr")
    public suspend fun deny(`value`: Output<List<Either<String, WebPubSubRequestType>>>) {
        this.deny = value
    }

    @JvmName("cqljeiqnojvsmswv")
    public suspend fun deny(vararg values: Output<Either<String, WebPubSubRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("jtnjmplnpngpimnp")
    public suspend fun deny(values: List<Output<Either<String, WebPubSubRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("qmqjswqaccusfyfd")
    public suspend fun allow(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("vgqjbmgshpkiacye")
    public suspend fun allow(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("xkbdcyexxxslcnad")
    public suspend fun deny(`value`: List<Either<String, WebPubSubRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("plgyrrfuyoxekexl")
    public suspend fun deny(vararg values: Either<String, WebPubSubRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    internal fun build(): NetworkACLArgs = NetworkACLArgs(
        allow = allow,
        deny = deny,
    )
}
